@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute the TF-IDF measure for ngram phrases
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Moo;
 use strictures 2;
@@ -12,6 +12,7 @@ use namespace::clean;
 use Carp;
 use Encode;
 use Lingua::EN::Ngram;
+use Lingua::StopWords qw( getStopWords );
 use List::Util qw( sum0 );
 
 
@@ -28,6 +29,13 @@ has size => (
 );
 
 
+has stopwords => (
+    is      => 'ro',
+    isa     => sub { croak 'Invalid Boolean' unless defined $_[0] },
+    default => sub { 1 },
+);
+
+
 has counts => (
     is       => 'ro',
     init_arg => undef,
@@ -52,9 +60,14 @@ sub _process_ngrams {
     my $ngram  = Lingua::EN::Ngram->new( file => $file );
     my $phrase = $ngram->ngram($size);
 
+    my $stop = getStopWords('en');
+
     my $hash;
 
     for my $p ( keys %$phrase ) {
+        next if $self->stopwords
+            && grep { $stop->{$_} } split /\s/, $p;  # Exclude stopwords
+
         $p =~ s/[\-?;:!,."\(\)]//g; # Remove unwanted punctuation
 
         # XXX Why are there are blanks in the returned phrases??
@@ -133,16 +146,22 @@ Text::TFIDF::Ngram - Compute the TF-IDF measure for ngram phrases
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
   use Text::TFIDF::Ngram;
   my @files = [qw( foo.txt bar.txt )];
-  my $size  = 3;
-  my $obj   = Text::TFIDF::Ngram->new( files => \@files, size => $size );
-  my $tfidf = $obj->tfidf_by_file;
-  print Dumper $tfidf;
+  my $obj   = Text::TFIDF::Ngram->new(
+    files     => \@files,
+    size      => 3,
+    stopwords => 1,
+  );
+  my $x = $obj->tf( 'foo.txt', 'foo' );
+  $x = $obj->idf('foo');
+  $x = $obj->tfidf( 'foo.txt', 'foo' );
+  $x = $obj->tfidf_by_file;
+  print Dumper $x;
 
 =head1 DESCRIPTION
 
@@ -164,6 +183,10 @@ ArrayRef of filenames.
 
 Integer ngram phrase size.
 
+=head2 stopwords
+
+Boolean indicating that phrases with stopwords will be ignored.  Default is 1.
+
 =head2 counts
 
 HashRef of the ngram counts of each processed file.
@@ -172,7 +195,11 @@ HashRef of the ngram counts of each processed file.
 
 =head2 new
 
-  $obj = Text::TFIDF::Ngram->new( files => \@files, size => $size );
+  $obj = Text::TFIDF::Ngram->new(
+    files     => \@files,
+    size      => $size,
+    stopwords => $stopwords,
+  );
 
 Create a new C<Text::TFIDF::Ngram> object.  If the B<files> argument is passed
 in, populates the object using those files.
